Module api

Module api 

TURN client API.

Provides a consistent interface between multiple implementations of TURN clients for different transports (TCP, and UDP) and wrappers (TLS).

Structs

DelayedTransmit
A Transmit where the data is some subset of the provided data.
Socket5Tuple
A socket with the specified network 5-tuple.
Transmit
A piece of data that needs to, or has been transmitted
TransmitBuild
A piece of data that needs to be built before it can be transmitted.
TurnConfig
Configuration structure for handling TURN client configuration.
TurnPeerData
Data that has been received from the TURN server.

Enums

BindChannelError
Errors produced when attempting to bind a channel.
CreatePermissionError
Errors produced when attempting to create a permission for a peer address.
Data
An owned or borrowed piece of data
DataRangeOrOwned
A slice range or an owned piece of data.
DelayedMessageOrChannelSend
A delayed Transmit that will produce data for a TURN server.
DeleteError
Errors produced when attempting to delete an allocation.
SendError
Errors produced when attempting to send data to a peer.
TcpAllocateError
Errors produced when attempting to connect to a peer over TCP.
TcpConnectError
Errors produced when attempting to connect to a peer over TCP.
TurnEvent
A set of events that can occur within a TURN client’s connection to a TURN server.
TurnPollRet
Return value from calling poll().
TurnRecvRet
Return value from call recv.

Traits

TurnClientApi
The public API of a TURN client.