#[non_exhaustive]pub enum BindChannelError {
AlreadyExists,
ExpiredChannelExists(Instant),
NoAllocation,
}Expand description
Errors produced when attempting to bind a channel.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyExists
The channel identifier already exists and cannot be recreated.
ExpiredChannelExists(Instant)
The channel for requested peer address has expired and cannot be recreated yet.
NoAllocation
There is no connection to the TURN server that can handle this channel.