#[non_exhaustive]pub enum SendError {
NoAllocation,
NoPermission,
NoTcpSocket,
}Expand description
Errors produced when attempting to send data to a peer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoAllocation
There is no connection to the TURN server.
NoPermission
There is no permission installed for the requested peer.
NoTcpSocket
There is no local TCP socket for the requested peer.