#[non_exhaustive]pub enum TcpConnectError {
AlreadyExists,
NoAllocation,
NoPermission,
}Expand description
Errors produced when attempting to connect to a peer over TCP.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyExists
The TCP connection already exists and cannot be recreated.
NoAllocation
There is no connection to the TURN server that can handle this TCP socket.
NoPermission
There is no permission installed for the requested peer.