pub enum TurnEvent {
AllocationCreated(TransportType, SocketAddr),
AllocationCreateFailed(AddressFamily),
PermissionCreated(TransportType, IpAddr),
PermissionCreateFailed(TransportType, IpAddr),
ChannelCreated(TransportType, SocketAddr),
ChannelCreateFailed(TransportType, SocketAddr),
TcpConnected(SocketAddr),
TcpConnectFailed(SocketAddr),
}Expand description
A set of events that can occur within a TURN client’s connection to a TURN server.
Variants
AllocationCreated(TransportType, SocketAddr)
An allocation was created on the server for the client. The allocation as the associated transport and address.
AllocationCreateFailed(AddressFamily)
Allocation failed to be created for the specified address family.
PermissionCreated(TransportType, IpAddr)
A permission was created for the provided transport and IP address.
PermissionCreateFailed(TransportType, IpAddr)
A permission could not be installed for the provided transport and IP address.
ChannelCreated(TransportType, SocketAddr)
A channel was created for the provided transport and IP address.
ChannelCreateFailed(TransportType, SocketAddr)
A channel could not be installed for the provided transport and IP address.
TcpConnected(SocketAddr)
A TCP connection was created for the provided peer IP address.
TcpConnectFailed(SocketAddr)
A TCP connection could not be installed for the provided peer IP address.