pub enum TurnPollRet {
WaitUntil(Instant),
AllocateTcpSocket {
id: u32,
socket: Socket5Tuple,
peer_addr: SocketAddr,
},
TcpClose {
local_addr: SocketAddr,
remote_addr: SocketAddr,
},
Closed,
}Expand description
Return value from calling poll().
Variants
WaitUntil(Instant)
The caller should wait until the provided time. Other events may cause this value to modified and poll() should be rechecked.
AllocateTcpSocket
The caller should initiate a connection using the provided remote address based on the provided local address.
Fields

socket: Socket5TupleThe client-server network 5-tuple.

peer_addr: SocketAddrThe address of the peer to connect to.
TcpClose
The client has completed closing a TCP connection between the TURN client and a peer.
The connection can be in progress of being setup.
Fields

local_addr: SocketAddrThe socket address local to the TURN client.

remote_addr: SocketAddrThe address of the remote peer.
Closed
The connection is closed and no further progress will be made.