TurnPollRet

Enum TurnPollRet 

pub enum TurnPollRet {
    WaitUntil(Instant),
    AllocateTcpSocket {
        id: u32,
        socket: Socket5Tuple,
        peer_addr: SocketAddr,
    },
    TcpClose {
        local_addr: SocketAddr,
        remote_addr: SocketAddr,
    },
    Closed,
}
Return value from calling poll().

Variants



WaitUntil(Instant)

The caller should wait until the provided time. Other events may cause this value to modified and poll() should be rechecked.



AllocateTcpSocket

The caller should initiate a connection using the provided remote address based on the provided local address.

Fields

id: u32

The server-unique identifier for this connection.

socket: Socket5Tuple

The client-server network 5-tuple.

peer_addr: SocketAddr

The address of the peer to connect to.



TcpClose

The client has completed closing a TCP connection between the TURN client and a peer.

The connection can be in progress of being setup.

Fields

local_addr: SocketAddr

The socket address local to the TURN client.

remote_addr: SocketAddr

The address of the remote peer.



Closed

The connection is closed and no further progress will be made.